from django import forms

class ContactForm(forms.Form):

    name = forms.CharField(
            widget=forms.TextInput(
                attrs={'placeholder': 'What is your name?'}))
    subject = forms.CharField(
            widget=forms.TextInput(
                attrs={'placeholder': 'What do you want to talk about?'}))
    email = forms.EmailField(
            widget=forms.TextInput(
                attrs={'placeholder': 'Where should we reply?'}))
    m = forms.CharField(
            label='Your Message',
            widget=forms.Textarea(
                attrs={'placeholder': 'What do you want to say?'}))
    phone = forms.CharField(
            required=False)
    # this field is a honeypot trap
    message = forms.CharField(
            widget=forms.Textarea(),
            required=False)



from mailer import send_html_mail
from django.utils.html import strip_tags
from django.template import loader, Context
from cccontact import settings as c_settings

def send_contact_form_email(sender, request, form, **kwargs):
    """sends the email from the contact form"""
    data = form.cleaned_data
    # render the plain text template
    t = loader.get_template('cccontact/message.txt')
    c = Context({
        'email': data.get('email'),
        'name': data.get('name'),
        'message': data.get('m'),
        'phone': data.get('phone')})
    message = t.render(c)
    print c_settings.RECIPIENTS
    
    send_html_mail(
            data['subject'],
            strip_tags(message),
            message,
            data['email'],
            c_settings.RECIPIENTS)



try:
    from django.conf.urls import patterns, include, url
except ImportError:
    from django.conf.urls.defaults import *

urlpatterns = patterns('',
    url(r'^complete/$', 'cccontact.views.complete', name='complete'),
    url(r'^$', 'cccontact.views.contact', name='contact')
)



from django.db import models
from cccontact import listeners
from cccontact import signals


signals.contact_form_is_valid.connect(
        listeners.send_contact_form_email,
        sender=None,
        dispatch_uid='send_contact_form_email')



from django.test import TestCase
from django.core.urlresolvers import reverse
from cccontact.tests.mock import MockRequest
from cccontact.views import contact, complete
from mailer.models import Message

class ViewTestCases(TestCase):

    def setUp(self):
        self.rf = MockRequest()

    def test_complete_200(self):
        """The complete page renders with 200 response"""
        request = self.rf.get(reverse('cccontact:complete'))
        response = complete(request)
        self.assertEqual(200, response.status_code)

    def test_contact_200__get(self):
        """The contact view gives a 200 status"""
        request = self.rf.get(reverse('cccontact:contact'))
        response = contact(request)
        self.assertEqual(200, response.status_code)

    def test_contact_200_post(self):
        """The contact view gives a 200 status"""
        request = self.rf.post(
                reverse('cccontact:contact'),
                {})
        response = contact(request)
        self.assertEqual(200, response.status_code)

    def test_contact_honeypot(self):
        """if data is entered into the honeypot then abort,
        but do so silently and return a 200"""
        self.assertEqual(0, Message.objects.count())
        # send data including honeypot
        data = {
                'name': 'Tester',
                'subject': 'Oh HAI',
                'email': 'spammer@spam.com',
                'message': 'buy viagra',
                'phone': '9789789',
                'm': 'buy viagra'}
        request = self.rf.post(
                reverse('cccontact:contact'),
                data)
        response = contact(request)
        # 200 response
        self.assertEqual(200, response.status_code)
        # no messages
        self.assertEqual(0, Message.objects.count())


    def test_send(self):
        """if the correcy data is sent, then a message is sent"""
        self.assertEqual(0, Message.objects.count())
        # send data including honeypot
        data = {
                'name': 'Tester',
                'subject': 'I want to buy',
                'email': 'customer@customer.com',
                'phone': '9789789',
                'm': 'I want to buy all the things'}
        request = self.rf.post(
                reverse('cccontact:contact'),
                data)
        response = contact(request)
        # 200 response
        self.assertEqual(302, response.status_code)
        # no messages
        self.assertEqual(1, Message.objects.count())



from django.core.urlresolvers import reverse
from django.contrib import messages
from django.http import HttpResponse, HttpResponseRedirect, Http404
from django.shortcuts import render_to_response, get_object_or_404
from django.template import RequestContext
from cccontact import settings as c_settings
from cccontact.signals import contact_form_is_valid


def complete(request):
    return render_to_response(
            'cccontact/complete.html',
            {},
            context_instance=RequestContext(request))

def contact(request):
    # get the forms and the model
    form_cls = c_settings.FORM

    # make the form
    form = form_cls()

    # process post
    if request.method == 'POST':
        form = form_cls(request.POST)
        if form.is_valid() and request.POST.get('message') == None:
            #form.save()
            responses = contact_form_is_valid.send(
                    sender=None,
                    request=request,
                    form=form)
            messages.success(request, 'Your message has been sent')
            return HttpResponseRedirect(reverse('cccontact:complete'))
        # not valid - set a message
        messages.error(request,
                'There are a few errors with the information you\'ve'\
                ' entered, correct them and try again')

    # return the response
    return render_to_response(
            'cccontact/contact.html',
            {'form': form},
            context_instance=RequestContext(request))



from django.test import TestCase
from django.core.urlresolvers import reverse
from cccontact.tests.mock import MockRequest
from cccontact.views import contact
from cccontact.signals import contact_form_is_valid

testdict = {}

class SignalTestCases(TestCase):

    def setUp(self):
        # set up test dict
        global testdict
        testdict = {'signal_sent': False}
        # set up request factory
        self.rf = MockRequest()
        # set up the data
        data = {
                'name': 'Tester',
                'subject': 'I want to buy',
                'email': 'customer@customer.com',
                'phone': '9789789',
                'm': 'I want to buy all the things'}
        # make the request
        self.request = self.rf.post(
                reverse('cccontact:contact'),
                data)

    def tearDown(self):
        # disconnect signals
        contact_form_is_valid.disconnect(
                dispatch_uid='test_contact_form_is_valid_sends')
        contact_form_is_valid.disconnect(
                dispatch_uid='test_sends_correct_arguments')

    def test_sends_correct_arguments(self):
        """"test that the view passes the signal the correct args"""
        global testdict
        # the listener
        def test_listener(sender, request, form, **kwargs):
            global testdict
            testdict['request'] = request
            testdict['form'] = form
        # connect it
        contact_form_is_valid.connect(
                test_listener,
                dispatch_uid='test_sends_correct_arguments')
        # now get the response
        response = contact(self.request)
        # test dict has been updated
        self.assertTrue(testdict['request'], True)
        self.assertTrue(testdict['form'], True)

    def test_contact_form_is_valid_sends(self):
        """when the contact form is valid the valid signal is sent"""
        # our test dict confirms that the signal not sent
        global testdict
        self.assertEqual(testdict['signal_sent'], False)
        # test listener
        def test_listener(**kwargs):
            global testdict
            testdict['signal_sent'] = True
        # connect it
        contact_form_is_valid.connect(
                test_listener,
                dispatch_uid='test_contact_form_is_valid_sends')
        # now get the response
        response = contact(self.request)
        # test dict has been updated
        self.assertEqual(testdict['signal_sent'], True)



from django.test import TestCase
from django.core.urlresolvers import reverse
from mailer.models import Message
from cccontact.tests.mock import MockRequest
from cccontact.views import contact
from cccontact.signals import contact_form_is_valid



class ListenerTestCases(TestCase):


    def setUp(self):
        # set up request factory
        self.rf = MockRequest()

    def test_badheadererror_subject(self):
        """BadHeaderError are handled gracefully"""
        # none
        self.assertEqual(0, Message.objects.count())
        # set up
        data = {
                'name': 'Tester',
                'subject': 'I want to buy\n\n\ncc:a@a.com',
                'email': 'customer@customer.com',
                'phone': '9789789',
                'm': 'I want to buy all the things'}
        # post it
        request = self.rf.post(
                reverse('cccontact:contact'),
                data)
        # get response
        response = contact(request)
        # now have one
        self.assertEqual(1, Message.objects.count())



import os
from distutils.core import setup
from cccontact import get_version

root_dir = os.path.dirname(__file__)
if root_dir != '':
    os.chdir(root_dir)

setup(
    name='django-cccontact',
    version=get_version(),
    license='BSD 3 Clause',
    description='A minimal contact form application for django',
    long_description=open('README.rst').read(),
    author='c&c Design Consultants',
    author_email='studio@designc.co.uk',
    url='https://github.com/designcc/django-cccontact',
    package_data={
        'cccontact' : [
            'templates/cccontact/*.html',
            'templates/cccontact/*.txt',
            'static/cccontact/js/*.js',
        ],
    },
    packages=[
        'cccontact',
        'cccontact.templatetags',
        'cccontact.tests'
    ],
    install_requires=[
        'django-mailer==0.2a1'],
    dependency_links = ['https://github.com/designcc/django-mailer/zipball/master#egg=django-mailer-0.2a1'])



from django.test import TestCase
from django.conf import settings
from cccontact import settings as c_settings

# ------------------------ FAKES
class FakeForm(object):
    """Does nothing. Used in the testcases"""


#------------------------ TEST CASES
class SettingTestCases(TestCase):

    def setUp(self):
        reload(c_settings)

    def tearDown(self):
        try:
            del(settings.CCCONTACT_MODEL)
        except AttributeError:
            pass
        try:
            del(settings.CCCONTACT_FORM)
        except AttributeError:
            pass


    def test_default_form(self):
        """The cccontact.forms.ContactForm form is the default form"""
        self.assertEqual(
                c_settings.FORM.__name__,
                'ContactForm')

    def test_custom_form(self):
        """The custom form can be overridden"""
        # set thesettings.CCCONTACT_FORM custom form
        settings.CCCONTACT_FORM = 'cccontact.tests.test_settings.FakeForm'
        reload(c_settings)
        # we have the fake form
        self.assertEqual('FakeForm', c_settings.FORM.__name__)



from django.conf import settings
from cccontact import import_thing

"""The address to send email to"""
RECIPIENTS = getattr(
        settings,
        'CCCONTACT_RECIPIENTS',
        [settings.DEFAULT_FROM_EMAIL,])


"""The form to be used"""
try:
    module, form = import_thing(settings.CCCONTACT_FORM)
except (AttributeError, ImportError):
    module, form = import_thing('cccontact.forms.ContactForm')

FORM = form



from django.utils.importlib import import_module

version = (1, '6', '3')

def get_version():
    """returns a pep complient version number"""
    return '.'.join(str(i) for i in version)

def import_thing(thing):
    """Attempts to import a thing (function, model, form etc)from django's
    import_module doesn't catch any exceptions"""
    # split the path
    parts = thing.split('.')
    # septerate the thing from the path
    thing_cls_name = parts.pop()
    # rebuild the module path
    module = import_module('.'.join(parts))
    # import the thing
    thing = getattr(module, thing_cls_name)
    # return the module and the thing
    return module, thing
